Welcome to ClientVPS Mirrors

Help for package shinyMonacoEditor
Type: Package
Title: The 'Monaco' Editor in 'Shiny'
Version: 1.1.0
Description: A 'Shiny' app including the 'Monaco' editor. The 'Monaco' editor is the code editor which powers 'VS Code'. It is particularly well developed for 'JavaScript'. In addition to the 'Monaco' editor features, the app provides prettifiers and minifiers for multiple languages, 'SCSS' and 'TypeScript' compilers, code checking for 'C' and 'C++' (requires 'cppcheck').
URL: https://github.com/stla/shinyMonacoEditor
BugReports: https://github.com/stla/shinyMonacoEditor/issues
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: shiny
Suggests: shinythemes, tools, styler, formatR, uchardet, shinyjqui, xml2
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2020-10-14 13:14:35 UTC; stla
Author: Stéphane Laurent [aut, cre], Microsoft Corporation [ctb, cph] (Monaco Editor), Brijesh Brittu [ctb, cph] (monaco-ace-tokenizer), James Long and contributors [ctb, cph] (Prettier), Leandro Vital [ctb, cph] (Bootstrap Flash Alert), Daniel Eden [ctb, cph] (animate.css), Adam Schwartz [ctb, cph] (chrome-tabs), David DeSandro [ctb, cph] (Draggabilly), JakubPawlowicz.com [ctb, cph] (clean-css), Mihai Bazon [ctb, cph] (terser), Juriy "kangax" Zaytsev [ctb, cph] (HTMLMinifier), Rodney Rehm [ctb, cph] (Sass.js), Rich Harris [ctb, cph] (svg-parser), Lionel Tzatzkin [ctb, cph] (scale-that-svg), Andrei Kashcha [ctb, cph] (panzoom), Vitaly Puzrin [ctb, cph] (markdown-it), Alex Kocharin [ctb, cph] (markdown-it), John Schlinkert [ctb, cph] (word-wrap), Terence Eden [ctb, cph] (SuperTinyIcons), www.jeasyui.com [ctb, cph] (EasyUI)
Maintainer: Stéphane Laurent <laurent_step@outlook.fr>
Repository: CRAN
Date/Publication: 2020-10-14 13:30:03 UTC

Monaco Editor in Shiny

Description

Launch a Shiny app with the Monaco editor.

Usage

shinyMonacoEditor(indentSize = 2)

Arguments

indentSize

an integer, at least 2, the number of spaces of the indentation

Examples

if(interactive()){
  shinyMonacoEditor()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.